quantizationtools.QEventSequence
================================

.. abjad-lineage:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence

.. autoclass:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.duration_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.count
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.from_millisecond_durations
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.from_millisecond_offsets
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.from_millisecond_pitch_pairs
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.from_tempo_scaled_durations
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.from_tempo_scaled_leaves
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.index
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__add__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__contains__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__getitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__getslice__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__hash__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__iter__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__len__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__mul__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.QEventSequence.__rmul__
   :noindex:
